@@ -129,6 +129,19 @@ class Dialcentral(object):
 		):
 			hildonize.hildonize_scrollwindow_with_viewport(self._widgetTree.get_widget(scrollingWidget))
 
+		for button in (
+			"back",
+			"sendSmsButton",
+			"cancelSmsButton",
+			"sms_button",
+			"dial_button",
+			"select_button",
+			"cancel_button",
+			"minutesEntryButton",
+			"clearcookies",
+		):
+			hildonize.set_button_thumb_selectable(button)
+
 		replacementButtons = [gtk.Button("Test")]
 		menu = hildonize.hildonize_menu(
 			self._window,
