@@ -434,6 +434,8 @@ class GVDialer(object):
 			callbackNumber = match.group(2)
 			callbackName = match.group(1)
 			self._callbackNumbers[callbackNumber] = callbackName
+		if len(self._callbackNumbers) == 0:
+			_moduleLogger.debug("Could not extract callback numbers from GoogleVoice (the troublesome page follows):\n%s" % page)
 
 	def _send_validation(self, number):
 		if not self.is_valid_syntax(number):
